/**
 * OAuth/OIDC SDK
 * Ping Identity
 * @author Technical Enablement Demo Team
 * @description The main entry point for your application's integration.
 */
import { ClientOptions, OpenIdConfiguration, TokenResponse } from './types';
/**
 * Class representing the OIDC client. The main interface to the SDK.
 */
export declare class OidcClient {
    private readonly clientOptions;
    private readonly issuerConfiguration;
    private readonly logger;
    private readonly clientStorage;
    private readonly browserUrlManager;
    /**
     * It is recommended to initialize this class using the initializeFromOpenIdConfig method which allows the open id configuration to be built
     * from your issuer's well-known endpoint. However if you wish, you can initialize the OidcClient class manually passing
     * in the OpenIdConfiguration manually.
     *
     * @param clientOptions {ClientOptions} Options for the OIDC Client, client_id is required
     * @param issuerConfig {OpenIdConfiguration} OpenIdConfiguration object that the library will use
     */
    constructor(clientOptions: ClientOptions, issuerConfig: OpenIdConfiguration);
    /**
     * Whether there is a token managed by the library available
     */
    hasToken(): Promise<boolean>;
    /**
     * Asynchronous wrapper around the constructor that allows apps to wait for a potential token
     * to be extracted/retrieved when initializing an OidcClient object.
     *
     * @param clientOptions {ClientOptions} Options for the OIDC Client, client_id is required
     * @param issuerConfig {OpenIdConfiguration} OpenIdConfiguration object that the library will use
     * @returns {Promise<OidcClient>} Promise that will resolve with an OidcClient
     */
    static initializeClient(clientOptions: ClientOptions, issuerConfig: OpenIdConfiguration): Promise<OidcClient>;
    /**
     * Creates the client-options object for you using the metadata from your authorization servers well-known endpoint.
     *
     * @param issuerUrl {string} Base URL for the issuer, /.well-known/openid-configuration will be appended in this method
     * @param clientOptions {ClientOptions} Options for the OIDC Client, client_id is required
     * @returns {object}
     * @see https://www.rfc-editor.org/rfc/rfc8414.html#section-3
     * @see https://openid.net/specs/openid-connect-discovery-1_0.html#IssuerDiscovery
     */
    static initializeFromOpenIdConfig(issuerUrl: string, clientOptions: ClientOptions): Promise<OidcClient>;
    /**
     * Takes an optional login_hint and navigates the browser to the generated authorize endpoint using window.location.assign
     *
     * @param loginHint {string} login_hint url parameter that will be appended to URL in case you have a username/email already
     * @returns {Promise} Will navigate the current browser tab to the authorization url that is generated through the authorizeUrl method
     * @see https://www.rfc-editor.org/rfc/rfc6749#section-3.1
     */
    authorize(loginHint?: string, silentAuthN?: boolean, popupRef?: Window): Promise<void | TokenResponse>;
    /**
     * Used to pass in a window reference to authorize function which allows popup window to work on safari (iPhone and macOS)
     * this is basically a convience method to make the public API cleaner
     *
     * @param popupRef {Window} window reference returned from window.open() call
     * @param loginHint {string} optional - login_hint url parameter that will be appended to URL in case you have a username/email already
     * @returns {Promise<TokenResponse>} - Will return a TokenResponse after after authentication is completed through the popup
     */
    authorizeWithPopup(popupRef: Window, loginHint?: string): Promise<TokenResponse>;
    /**
     * Takes an optional login_hint and returns a Promise containing the url you will redirect the user to.
     * Typically you will want to apply the url to an anchor tag or redirect to it using window.location.assign(xxx).
     *
     * @param loginHint {string} login_hint url parameter that will be appended to URL in case you have a username/email already
     * @param silentAuthN {boolean} If true, silent authentication is initiated
     * @returns {Promise<string>} Promise that will resolve with a url you should redirect to
     * @see https://openid.net/specs/openid-connect-core-1_0.html#ThirdPartyInitiatedLogin
     * @see https://www.rfc-editor.org/rfc/rfc6749#section-4
     */
    authorizeUrl(loginHint?: string, silentAuthN?: boolean): Promise<string>;
    /**
     * Get a token. It will check for tokens in the following order:
     *
     * 1. Previously stored token
     * 2. Token from the URL Hash (implicit)
     * 3. Token from the authorization server (authorization_code, grant_type: 'authorization_code' or default)
     *
     * Getting a token from the authorization server requires a 'code' url parameter or manually passing in the code if you'd like to manage it yourself.
     * Please note if the token or code is retrieved from the url it will automatically be removed from the URL and browser history after the library has
     * a token.
     *
     * @returns Token response from auth server
     * @see https://www.rfc-editor.org/rfc/rfc6749#section-4.1.3
     * @see https://www.rfc-editor.org/rfc/rfc6749#section-4.2
     * @see https://www.rfc-editor.org/rfc/rfc6749#section-4.1
     */
    getToken(urlOverride?: string): Promise<TokenResponse>;
    /**
     * Revoke the token managed by the library
     *
     * @returns {any} - HTTP response 200 only.
     * @see https://www.rfc-editor.org/rfc/rfc7009#section-2
     */
    revokeToken(): Promise<any>;
    /**
     * Get a new access token using refresh token.
     *
     * @returns Token response from auth server
     * @see https://www.rfc-editor.org/rfc/rfc6749#section-6
     */
    refreshToken(): Promise<TokenResponse | void>;
    /**
     * End the users session using the end_session_endpoint from the issuer, the id token will be automatically appended
     * to the url via the id_token_hint url parameter if it is available. This call will redirect the browser tab to the signoff
     * endpoint so it does not return anything.
     *
     * @param postLogoutRedirectUri {string} optional url to redirect user to after their session has been ended
     */
    endSession(postLogoutRedirectUri?: string): Promise<void>;
    /**
     * Retrieve the User Info from the issuer, uses OpenIdConfiguration from the server and the token managed by the library
     *
     * @returns {any} User Info returned from the issuer
     * @see https://openid.net/specs/openid-connect-core-1_0.html#UserInfo
     */
    fetchUserInfo<T>(): Promise<T>;
    private verifyToken;
    private authenticationServerApiCall;
}
